<?php
/**
 * Core file.
 *
 * This is the template that includes all the other files for core featured of Theme Palace
 *
 * @package Theme Palace
 * @subpackage Personify
 * @since Personify 0.1
 */

/**
 * Include options function.
 */
require get_template_directory() . '/inc/options.php';


// Load customizer defaults values
require get_template_directory() . '/inc/customizer/defaults.php';

/**
 * Function to detect SCRIPT_DEBUG on and off.
 * @return string If on, empty else return .min string.
 */
function personify_min() {
	return defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ? '' : '.min';
}

/**
 * Merge values from default options array and values from customizer
 *
 * @return array Values returned from customizer
 * @since Personify 0.1
 */
function personify_get_theme_options() {
  $personify_default_options = personify_get_default_theme_options();

  return array_merge( $personify_default_options , get_theme_mod( 'personify_theme_options', $personify_default_options ) ) ;
}

/**
 * Load admin custom styles
 */
function personify_load_admin_style() {
    wp_register_style( 'load_admin_css', get_template_directory_uri() . '/assets/css/admin-style' . personify_min() . '.css', false, '1.0.0' );
    wp_enqueue_style( 'load_admin_css' );
}
add_action( 'admin_enqueue_scripts', 'personify_load_admin_style' );

/**
 * Add breadcrumb functions.
 */
require get_template_directory() . '/inc/breadcrumb-class.php';

/**
 * Add helper functions.
 */
require get_template_directory() . '/inc/helpers.php';

/**
 * Add structural hooks.
 */
require get_template_directory() . '/inc/structure.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer/customizer.php';

/**
 * Home page Sections
 */
require get_template_directory() . '/inc/sections/sections.php';

/**
 * Metabox additions.
 */
require get_template_directory() . '/inc/metabox.php';

/**
 * Custom widget additions.
 */
require get_template_directory() . '/inc/widgets/widgets.php';

/**
* TGM plugin additions.
*/
require get_template_directory() . '/inc/tgm-plugin/tgm-hook.php';

