<?php
/**
 * Event Section options
 *
 * @package Theme Palace
 * @subpackage Personify
 * @since Personify 0.1
 */

// Add Event section
$wp_customize->add_section( 'personify_event_section', array(
	'title'             => esc_html__( 'Event Section','personify' ),
	'description'       => esc_html__( 'Event Section options.', 'personify' ),
	'panel'             => 'personify_front_page_panel',
) );

// Event content enable control and setting
$wp_customize->add_setting( 'personify_theme_options[event_section_enable]', array(
	'default'			=> 	$options['event_section_enable'],
	'sanitize_callback' => 'personify_sanitize_switch_control',
) );

$wp_customize->add_control( new Personify_Switch_Control( $wp_customize, 'personify_theme_options[event_section_enable]', array(
	'label'             => esc_html__( 'Event Section Enable', 'personify' ),
	'section'           => 'personify_event_section',
	'on_off_label' 		=> personify_enable_options(),
) ) );

// Event title setting and control
$wp_customize->add_setting( 'personify_theme_options[event_section_title]', array(
	'default' 			=> $options['event_section_title'],
	'sanitize_callback' => 'sanitize_text_field',
	'transport'			=> 'postMessage'
) );

$wp_customize->add_control( 'personify_theme_options[event_section_title]', array(
	'label'           	=> esc_html__( 'Event Title', 'personify' ),
	'section'        	=> 'personify_event_section',
	'active_callback' 	=> 'personify_is_event_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'personify_theme_options[event_section_title]', array(
		'selector'            => '#upcoming-events .wrapper .section-header h2.section-title',
		'settings'            => 'personify_theme_options[event_section_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'personify_event_title_partial',
    ) );
}

// Add dropdown category setting and control.
$wp_customize->add_setting(  'personify_theme_options[event_content_category]', array(
	'sanitize_callback' => 'personify_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Personify_Dropdown_Taxonomies_Control( $wp_customize,'personify_theme_options[event_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'personify' ),
	'description'      	=> esc_html__( 'Note: Latest Three posts will be shown from selected category', 'personify' ),
	'section'           => 'personify_event_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'personify_is_event_section_enable'
) ) );

// Event additional image setting and control.
$wp_customize->add_setting( 'personify_theme_options[event_background_image]', array(
	'sanitize_callback' => 'personify_sanitize_image',
) );

$wp_customize->add_control(
	new WP_Customize_Image_Control( $wp_customize, 'personify_theme_options[event_background_image]',
		array(
		'label'       		=> esc_html__( 'Select Background Image', 'personify' ),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'personify' ), 1920, 1080 ),
		'section'     		=> 'personify_event_section',
		'active_callback'	=> 'personify_is_event_section_enable',
) ) );

for ( $i = 1; $i <= 2; $i ++ ) {
	// Event social link setting and control
	$wp_customize->add_setting( 'personify_theme_options[event_social_link_' . $i . ']', array(
		'default' 			=> $options['event_social_link'],
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control( 'personify_theme_options[event_social_link_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Social Link %d', 'personify' ), $i),
		'section'        	=> 'personify_event_section',
		'active_callback' 	=> 'personify_is_event_section_enable',
		'type'				=> 'url',
	) );

	// Event social link setting and control
	$wp_customize->add_setting( 'personify_theme_options[event_social_label_' . $i . ']', array(
		'default' 			=> $options['event_social_label'],
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'personify_theme_options[event_social_label_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Social Link Label %d', 'personify' ), $i),
		'section'        	=> 'personify_event_section',
		'active_callback' 	=> 'personify_is_event_section_enable',
		'type'				=> 'text',
	) );
}