<?php
/**
 * Custom functions that act independently of the theme templates.
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package Theme Palace
 * @subpackage Personify
 * @since Personify 0.1
 */

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function personify_body_classes( $classes ) {
	$options = personify_get_theme_options();

	// Adds a class of group-blog to blogs with more than 1 published author.
	if ( is_multi_author() ) {
		$classes[] = 'group-blog';
	}

	// Adds a class of hfeed to non-singular pages.
	if ( ! is_singular() ) {
		$classes[] = 'hfeed';
	}

	// blog view
	$classes[] = 'list';

	// single view
	$classes[] = 'post-share-disabled';

	// Add a class for layout
	$classes[] = esc_attr( $options['site_layout'] );

	if ( ! $options['testimonial_section_enable'] ) {
		$classes[] = 'testimonial-section-disabled';
	}

	if ( is_singular( 'page' ) ) {
		if ( ! has_post_thumbnail() ) 
			$classes[] = 'no-page-thumbnail';
	}

	if ( is_singular() ) {
		$stored_sidebar_position = get_post_meta( get_the_id(), 'personify-sidebar-position', true );
		$stored_sidebar_position = ! empty( $stored_sidebar_position ) ? $stored_sidebar_position : 'page-full-width';
		$classes[] = $stored_sidebar_position;
	}

	return $classes;
}
add_filter( 'body_class', 'personify_body_classes' );
