<?php
/**
 * Event section
 *
 * This is the template for the content of event section
 *
 * @package Theme Palace
 * @subpackage Personify
 * @since Personify 0.1
 */
if ( ! function_exists( 'personify_add_event_section' ) ) :
    /**
    * Add event section
    *
    *@since Personify 0.1
    */
    function personify_add_event_section() {
        // Check if event is enabled on frontpage
        $event_enable = apply_filters( 'personify_section_status', true, 'event_section_enable' );

        if ( true !== $event_enable ) {
            return false;
        }
        // Get event section details
        $section_details = array();
        $section_details = apply_filters( 'personify_filter_event_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render event section now.
        personify_render_event_section( $section_details );
    }
endif;
add_action( 'personify_primary_content', 'personify_add_event_section', 80 );


if ( ! function_exists( 'personify_get_event_section_details' ) ) :
    /**
    * event section details.
    *
    * @since Personify 0.1
    * @param array $input event section details.
    */
    function personify_get_event_section_details( $input ) {
        $options = personify_get_theme_options();

        $content = array();

        $cat_id = ! empty( $options['event_content_category'] ) ? $options['event_content_category'] : '';
        $args = array(
            'post_type'         => 'post',
            'cat'               => absint( $cat_id ),
            'posts_per_page'    => 3,
            );                    

        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['excerpt']   = personify_trim_content( 23 );

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

    if ( ! empty( $content ) ) {
        $input = $content;
    }
    return $input;
    }
endif;
// event section content details.
add_filter( 'personify_filter_event_section_details', 'personify_get_event_section_details' );


if ( ! function_exists( 'personify_render_event_section' ) ) :
  /**
   * Start event section
   *
   * @return string event content
   * @since Personify 0.1
   *
   */
   function personify_render_event_section( $content_details = array() ) {
        $options = personify_get_theme_options();
        $background = ! empty( $options['event_background_image'] ) ? $options['event_background_image'] : '';
        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="upcoming-events" class="relative page-section" style="background-image:url('<?php echo esc_url( $background ); ?>');">
            <div class="black-overlay"></div>
            <div class="wrapper">
                <div class="section-content col-2">
                    <div class="column-wrapper">
                        <div class="follow-upcoming-events">
                            <?php for ( $i = 1; $i <= 2; $i++ ) :
                                $social_link = isset( $options['event_social_link_' . $i] ) ? $options['event_social_link_' . $i] : $options['event_social_link'];
                                $social_label = isset( $options['event_social_label_' . $i] ) ? $options['event_social_label_' . $i] : $options['event_social_label'];
                                if ( ! empty( $social_link ) ) : ?>
                                    <a href="<?php echo esc_url( $social_link ); ?>" target="_blank">
                                        <?php echo personify_return_social_icon( $social_link ); 

                                        if ( ! empty( $social_label ) ) : ?>
                                            <span><?php echo esc_html( $social_label ); ?></span>
                                        <?php endif; ?>
                                    </a>
                                <?php endif; 
                            endfor; ?>
                        </div><!-- .follow-upcoming-events -->
                    </div><!-- .column-wrapper -->

                    <div class="column-wrapper events-column">
                        <?php if ( ! empty( $options['event_section_title'] ) ) : ?>
                            <div class="section-header">
                                <h2 class="section-title"><?php echo esc_html( $options['event_section_title'] ); ?></h2>
                            </div><!-- .section-header -->
                        <?php endif; ?>

                        <div class="events-wrapper">
                            <?php foreach ( $content_details as $content ) : ?>
                                <article id="event-01" class="hentry">

                                    <header class="entry-header">
                                        <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                    </header>

                                    <div class="entry-content"><?php echo esc_html( $content['excerpt'] ); ?></div><!-- .entry-content -->
                                    <div class="separator"></div>
                                </article>
                            <?php endforeach; ?>
                        </div><!-- .events-wrapper -->
                    </div><!-- .column-wrapper -->
                </div><!-- .section-content -->
            </div><!-- .wrapper -->
        </div><!-- #upcoming-events -->
    <?php }
endif;