<?php
/**
 * Testimonial section
 *
 * This is the template for the content of testimonial section
 *
 * @package Theme Palace
 * @subpackage Personify
 * @since Personify 0.1
 */
if ( ! function_exists( 'personify_add_testimonial_section' ) ) :
    /**
    * Add testimonial section
    *
    *@since Personify 0.1
    */
    function personify_add_testimonial_section() {
        // Check if testimonial is enabled on frontpage
        $testimonial_enable = apply_filters( 'personify_section_status', true, 'testimonial_section_enable' );

        if ( true !== $testimonial_enable ) {
            return false;
        }
        // Get testimonial section details
        $section_details = array();
        $section_details = apply_filters( 'personify_filter_testimonial_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render testimonial section now.
        personify_render_testimonial_section( $section_details );
    }
endif;
add_action( 'personify_primary_content', 'personify_add_testimonial_section', 90 );


if ( ! function_exists( 'personify_get_testimonial_section_details' ) ) :
    /**
    * testimonial section details.
    *
    * @since Personify 0.1
    * @param array $input testimonial section details.
    */
    function personify_get_testimonial_section_details( $input ) {
        $options = personify_get_theme_options();

        $content = array();

        $cat_id = ! empty( $options['testimonial_content_category'] ) ? $options['testimonial_content_category'] : '';
        $args = array(
            'post_type'         => 'post',
            'cat'               => absint( $cat_id ),
            'posts_per_page'    => 2,
            );                    

        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['excerpt']   = wpautop( personify_trim_content( 25 ) );
                $page_post['image']     = get_the_post_thumbnail_url( '', 'thumbnail' );

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

    if ( ! empty( $content ) ) {
        $input = $content;
    }
    return $input;
    }
endif;
// testimonial section content details.
add_filter( 'personify_filter_testimonial_section_details', 'personify_get_testimonial_section_details' );


if ( ! function_exists( 'personify_render_testimonial_section' ) ) :
  /**
   * Start testimonial section
   *
   * @return string testimonial content
   * @since Personify 0.1
   *
   */
   function personify_render_testimonial_section( $content_details = array() ) {
        $options = personify_get_theme_options();

        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="client-testimonial" class="relative page-section">
            <div class="wrapper">
                <?php if ( ! empty( $options['testimonial_title'] ) ) : ?>
                    <div class="section-header align-center">
                        <h2 class="section-title"><?php echo esc_html( $options['testimonial_title'] ); ?></h2>
                    </div><!-- .section-header -->
                <?php endif; ?>
                <div class="section-content">
                    <div class="testimonial-slider <?php echo ( count( $content_details ) === 1 ) ? 'one-item' : ''; ?>" data-slick='{"slidesToShow": <?php echo ( count( $content_details ) === 1 ) ? 1 : 2; ?>, "slidesToScroll": 1, "infinite": true, "speed": 1000, "dots": false, "arrows":true, "autoplay": true, "fade": false, "draggable": true }'>
                        <?php foreach ( $content_details as $content ) : ?>
                            <div class="slick-item">
                                <div class="client-wrapper">
                                    <img src="<?php echo esc_url( get_template_directory_uri() . '/assets/uploads/quote-gray.png' ); ?>" class="quote-icon" alt="<?php echo esc_attr( $content['title'] ); ?>">

                                    <?php if ( ! empty( $content['excerpt'] ) ) : ?>
                                        <div class="entry-content"><?php echo wp_kses_post( $content['excerpt'] ); ?></div><!-- .entry-content -->
                                    <?php endif; 

                                    if ( ! empty( $content['title'] ) ) : ?>
                                        <header class="entry-header">
                                            <h2 class="entry-title">
                                                <?php if ( ! empty( $content['url'] ) ) : ?>
                                                    <a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a>
                                                <?php else : 
                                                    echo esc_html( $content['title'] );
                                                endif; ?>
                                            </h2>
                                        </header>
                                    <?php endif;

                                    if ( ! empty( $content['image'] ) ) : ?>
                                        <div class="featured-image">
                                            <img src="<?php echo esc_url( $content['image'] ); ?>" alt="<?php echo esc_attr( $content['title'] ); ?>">
                                        </div><!-- .featured-image -->
                                    <?php endif; ?>
                                </div><!-- .client-wrapper -->
                            </div><!-- .slick-item -->
                        <?php endforeach; ?>
                    </div><!-- .testimonial-slider -->
                </div><!-- .section-content -->
            </div><!-- .wrapper -->
        </div><!-- #client-testimonial -->
    <?php }
endif;